#!/usr/local/bin/python
# -*- coding: utf-8 -*-
# file: brh.py

import re
from collections import OrderedDict
from .romanizer import romanizer

has_capitals = False

data = OrderedDict()

# https://en.wikipedia.org/wiki/Aramaic_alphabet
# https://en.wikipedia.org/wiki/Brahmi_script

# letters from 𑀅 to 𑀣
# alef:http://en.wiktionary.org/wiki/
data['a'] = dict(letter=[u'𑀅'], name=u'𑀅', segment='vowel', subsegment='', transliteration=u'a', order=1)
# beth:http://en.wiktionary.org/wiki/
data['ba'] = dict(letter=[u'𑀩'], name=u'𑀩', segment='consonant', subsegment='', transliteration=u'b', order=2)
# gimel:http://en.wiktionary.org/wiki/
data['ga'] = dict(letter=[u'𑀕'], name=u'𑀕', segment='consonant', subsegment='', transliteration=u'g', order=3)
# daleth:http://en.wiktionary.org/wiki/
data['dha'] = dict(letter=[u'𑀥'], name=u'𑀥', segment='consonant', subsegment='', transliteration=u'd', order=4)
# he:http://en.wiktionary.org/wiki/
data['ha'] = dict(letter=[u'𑀳'], name=u'𑀳', segment='vowel', subsegment='', transliteration=u'e', order=5)
# vau:http://en.wikipedia.org/wiki/
data['va'] = dict(letter=[u'𑀯'], name=u'𑀯', segment='vowel', subsegment='', transliteration=u'w', order=6)
# zayin:http://en.wiktionary.org/wiki/
data['ja'] = dict(letter=[u'𑀚'], name=u'𑀚', segment='consonant', subsegment='', transliteration=u'z', order=7)
# heth:http://en.wiktionary.org/wiki/
data['gha'] = dict(letter=[u'𑀖'], name=u'𑀖', segment='consonant', subsegment='', transliteration=u'ê', order=8)
# teth:http://en.wiktionary.org/wiki/
data['tha'] = dict(letter=[u'𑀣'], name=u'𑀣', segment='consonant', subsegment='', transliteration=u'h', order=9)

# letters from 𑀬 to 𑀲
# yod:http://en.wiktionary.org/wiki/
data['ya'] = dict(letter=[u'𑀬'], name=u'𑀬', segment='vowel', subsegment='', transliteration=u'i', order=10)
# kaph:http://en.wiktionary.org/wiki/
data['ka'] = dict(letter=[u'𑀓'], name=u'𑀓', segment='consonant', subsegment='', transliteration=u'k', order=11)
# lamed:http://en.wiktionary.org/wiki/
data['la'] = dict(letter=[u'𑀮'], name=u'𑀮', segment='consonant', subsegment='', transliteration=u'l', order=12)
# mem:http://en.wiktionary.org/wiki/
data['ma'] = dict(letter=[u'𑀫'], name=u'𑀫', segment='consonant', subsegment='', transliteration=u'm', order=13)
# num:http://en.wiktionary.org/wiki/
data['na'] = dict(letter=[u'𑀦'], name=u'𑀦', segment='consonant', subsegment='', transliteration=u'n', order=14)
# samekh:http://en.wiktionary.org/wiki/
data['sha'] = dict(letter=[u'𑀰'], name=u'𑀰', segment='consonant', subsegment='', transliteration=u'x', order=15)
# ayin:http://en.wiktionary.org/wiki/
data['e'] = dict(letter=[u'𑀏'], name=u'𑀏', segment='vowel', subsegment='', transliteration=u'o', order=16)
# pe:http://en.wiktionary.org/wiki/
data['pa'] = dict(letter=[u'𑀧'], name=u'𑀧', segment='consonant', subsegment='', transliteration=u'p', order=17)
# tsade:http://en.wikipedia.org/wiki/
data['sa'] = dict(letter=[u'𑀲'], name=u'𑀲', segment='consonant', subsegment='', transliteration=u'c', order=18)

# letters from 𑀔 to 𑀢
# resh:http://en.wiktionary.org/wiki/
data['kha'] = dict(letter=[u'𑀔'], name=u'𑀔', segment='consonant', subsegment='', transliteration=u'q', order=19)
# shin:http://en.wiktionary.org/wiki/
data['ra'] = dict(letter=[u'𑀭'], name=u'𑀭', segment='consonant', subsegment='', transliteration=u'r', order=20)
# tau:http://en.wiktionary.org/wiki/
data['ssa'] = dict(letter=[u'𑀱'], name=u'𑀱', segment='consonant', subsegment='', transliteration=u's', order=21)
# final_tsade:http://en.wiktionary.org/wiki/
data['ta'] = dict(letter=[u'𑀢'], name=u'𑀢', segment='consonant', subsegment='', transliteration=u't', order=22)
# final_kaph:http://en.wiktionary.org/wiki/
#data['final_kap'] = dict(letter=[u'ⲫ'], name=u'ⲫ', segment='consonant', subsegment='', transliteration=u'K', order=23)
# final_mem, chi:http://en.wiktionⲣary.org/wiki/
#data['final_mem'] = dict(letter=[u'ⲭ'], name=u'ⲭ', segment='consonant', subsegment='', transliteration=u'M', order=24)
# final_nun:http://en.wiktionary.org/wiki/
#data['final_nun'] = dict(letter=[u'ⲯ'], name=u'ⲯ', segment='consonant', subsegment='', transliteration=u'N', order=25)
# final_pe:http://en.wiktionary.org/wiki/
#data['final_pe'] = dict(letter=[u'ⲱ'], name=u'ⲱ', segment='consonant', subsegment='', transliteration=u'P', order=26)
# final_tsade:http://en.wiktionary.org/wiki/
#data['final_sadhe'] = dict(letter=[u'ⳁ'], name=u'ⳁ', segment='consonant', subsegment='', transliteration=u'Y', order=27)

r = romanizer(data, False)

# collect brahmic and transliteration letters from data dictionary for preprocessing function
letters = ''.join([''.join(d['letter'])+d['transliteration'] for key, d in data.items()])
regex = re.compile('[^%s ]+' % letters)
regex2 = re.compile('[^%s\s]' % ''.join([''.join(d['letter']) for key, d in data.items()]))

r = romanizer(data)

def filter(string):
    """
    Preprocess string to remove all other characters but brahmic ones

    :param string:
    :return:
    """
    # remove all unwanted characters
    return regex2.sub(' ', string)

def preprocess(string):
    """
    Preprocess string to transform all diacritics and remove other special characters

    :param string:
    :return:
    """
    return regex.sub('', string)

def convert(string, sanitize=False):
    """
    Swap characters from script to transliterated version and vice versa.
    Optionally sanitize string by using preprocess function.

    :param sanitize:
    :param string:
    :return:
    """
    return r.convert(string, (preprocess if sanitize else False))



#!/usr/local/bin/python
# -*- coding: utf-8 -*-
# file: heb.py

import re
from collections import OrderedDict
from .romanizer import romanizer

has_capitals = False

data = OrderedDict()

"""

Data mapping between hebrew letters and their linguistic components

http://en.wikipedia.org/wiki/Hebrew_alphabet

Segments:
- vowel
- consonant

Four vowels: א ה ו י (a e w i)

Transliteration: http://baytephraim.com/mobile_site/Hebrew.html

"""

# letters from א to ט (1 to 9)
# alef:http://en.wiktionary.org/wiki/
data['alef'] = dict(letter=[u'א'], name=u'אָלֶף', segment='vowel', subsegment='', transliteration=u'a', order=1)
# beth:http://en.wiktionary.org/wiki/
data['beth'] = dict(letter=[u'ב'], name=u'בֵּית', segment='consonant', subsegment='', transliteration=u'b', order=2)
# gimel:http://en.wiktionary.org/wiki/
data['gimel'] = dict(letter=[u'ג'], name=u'גִּימל', segment='consonant', subsegment='', transliteration=u'c', order=3)
# daleth:http://en.wiktionary.org/wiki/
data['daleth'] = dict(letter=[u'ד'], name=u'דָּלֶת', segment='consonant', subsegment='', transliteration=u'd', order=4)
# he:http://en.wiktionary.org/wiki/
data['he'] = dict(letter=[u'ה'], name=u'הי', segment='vowel', subsegment='', transliteration=u'e', order=5)
# vau:http://en.wikipedia.org/wiki/
data['vau'] = dict(letter=[u'ו'], name=u'ויו', segment='vowel', subsegment='', transliteration=u'f', order=6)
# zayin:http://en.wiktionary.org/wiki/
data['zayin'] = dict(letter=[u'ז'], name=u'זַיִן', segment='consonant', subsegment='', transliteration=u'z', order=7)
# heth:http://en.wiktionary.org/wiki/
data['heth'] = dict(letter=[u'ח'], name=u'חֵית', segment='consonant', subsegment='', transliteration=u'h', order=8)
# teth:http://en.wiktionary.org/wiki/
data['teth'] = dict(letter=[u'ט'], name=u'טֵית', segment='consonant', subsegment='', transliteration=u'u', order=9)

# letters from י to צ (10 to 90)
# yod:http://en.wiktionary.org/wiki/
data['yod'] = dict(letter=[u'י'], name=u'יוֹד', segment='vowel', subsegment='', transliteration=u'i', order=10)
# kaph:http://en.wiktionary.org/wiki/
data['kaph'] = dict(letter=[u'כ'], name=u'כַּף', segment='consonant', subsegment='', transliteration=u'k', order=11)
# lamed:http://en.wiktionary.org/wiki/
data['lamed'] = dict(letter=[u'ל'], name=u'לָמֶד', segment='consonant', subsegment='', transliteration=u'l', order=12)
# mem:http://en.wiktionary.org/wiki/
data['mem'] = dict(letter=[u'מ'], name=u'מֵם', segment='consonant', subsegment='', transliteration=u'm', order=13)
# num:http://en.wiktionary.org/wiki/
data['num'] = dict(letter=[u'נ'], name=u'נוּן', segment='consonant', subsegment='', transliteration=u'n', order=14)
# samekh:http://en.wiktionary.org/wiki/
data['samekh'] = dict(letter=[u'ס'], name=u'סָמֶך', segment='consonant', subsegment='', transliteration=u'x', order=15)
# ayin:http://en.wiktionary.org/wiki/
data['ayin'] = dict(letter=[u'ע'], name=u'עַיִן', segment='consonant', subsegment='', transliteration=u'o', order=16)
# pe:http://en.wiktionary.org/wiki/π
data['pe'] = dict(letter=[u'פ'], name=u'פה', segment='consonant', subsegment='', transliteration=u'p', order=17)
# tsade:http://en.wikipedia.org/wiki/Tsade
data['tsade'] = dict(letter=[u'צ'], name=u'צדיק', segment='consonant', subsegment='', transliteration=u'y', order=18)

# letters from ק to ץ (100 to 900)
# qoph:http://en.wiktionary.org/wiki/
data['qoph'] = dict(letter=[u'ק'], name=u'קוֹף', segment='consonant', subsegment='', transliteration=u'q', order=19)
# resh:http://en.wiktionary.org/wiki/
data['resh'] = dict(letter=[u'ר'], name=u'רֵישׂ', segment='consonant', subsegment='', transliteration=u'r', order=20)
# shin:http://en.wiktionary.org/wiki/
data['shin'] = dict(letter=[u'ש'], name=u'שִׁין', segment='consonant', subsegment='', transliteration=u's', order=21)
# tau:http://en.wiktionary.org/wiki/
data['tau'] = dict(letter=[u'ת'], name=u'תו', segment='consonant', subsegment='', transliteration=u't', order=22)
# final_kaph:http://en.wiktionary.org/wiki/
data['final_kaph'] = dict(letter=[u'ך'], name=u'כַף סוֹפִית', segment='consonant', subsegment='', transliteration=u'K', order=23)
# final_mem, chi:http://en.wiktionary.org/wiki/
data['final_mem'] = dict(letter=[u'ם'], name=u'מֵם סוֹפִית', segment='consonant', subsegment='', transliteration=u'M', order=24)
# final_nun:http://en.wiktionary.org/wiki/
data['final_nun'] = dict(letter=[u'ן'], name=u'נוּן סוֹפִית', segment='consonant', subsegment='', transliteration=u'N', order=25)
# final_pe:http://en.wiktionary.org/wiki/
data['final_pe'] = dict(letter=[u'ף'], name=u'פה סופית', segment='consonant', subsegment='', transliteration=u'P', order=26)
# final_tsade:http://en.wiktionary.org/wiki/Tsade
data['final_tsade'] = dict(letter=[u'ץ'], name=u'צדיק סופית', segment='consonant', subsegment='', transliteration=u'Y', order=27)

r = romanizer(data, False)

# collect hebrew and transliteration letters from data dictionary for preprocessing function
letters = ''.join([''.join(d['letter'])+d['transliteration'] for key, d in data.items()])
regex = re.compile('[^%s ]+' % letters)
regex2 = re.compile('[^%s\s]' % ''.join([''.join(d['letter']) for key, d in data.items()]))

def filter(string):
    """
    Preprocess string to remove all other characters but Hebrew ones and whitespace

    :param string:
    :return:
    """
    # remove all unwanted characters by replacing them with empty space
    # if removing all other characters then word divisioning might get lost and further
    # processing text would get difficult if not impossible
    return regex2.sub(' ', string)

def preprocess(string):
    """
    Preprocess string to transform all diacritics and remove other special characters than appropriate

    :param string:
    :return:
    """
    return regex.sub('', string)

def convert(string, sanitize=False):
    """
    Swap characters from script to transliterated version and vice versa.
    Optionally sanitize string by using preprocess function.

    :param sanitize:
    :param string:
    :return:
    """
    return r.convert(string, (preprocess if sanitize else False))



#!/usr/local/bin/python
# -*- coding: utf-8 -*-
# file: phn.py

import re
from collections import OrderedDict
from .romanizer import romanizer

has_capitals = False

data = OrderedDict()

# https://en.wikipedia.org/wiki/Aramaic_alphabet
# https://en.wikipedia.org/wiki/Phoenician_alphabet
# 1 = 𐤖 ‬
# 2 = 𐤚‬
# 3 = 𐤛
# 10 = 𐤗
# 20 = 𐤘
# 100 = 𐤙

# letters from 𐤀 to 𐤈
# alef:http://en.wiktionary.org/wiki/
data['alep'] = dict(letter=[u'𐤀'], name=u'𐤀', segment='vowel', subsegment='', transliteration=u'a', order=1)
# beth:http://en.wiktionary.org/wiki/
data['bet'] = dict(letter=[u'𐤁'], name=u'𐤁', segment='consonant', subsegment='', transliteration=u'b', order=2)
# gimel:http://en.wiktionary.org/wiki/
data['giml'] = dict(letter=[u'𐤂‬'], name=u'𐤂‬', segment='consonant', subsegment='', transliteration=u'g', order=3)
# daleth:http://en.wiktionary.org/wiki/
data['dalet'] = dict(letter=[u'𐤃‬'], name=u'𐤃‬', segment='consonant', subsegment='', transliteration=u'd', order=4)
# he:http://en.wiktionary.org/wiki/
data['he'] = dict(letter=[u'𐤄‬'], name=u'𐤄‬', segment='vowel', subsegment='', transliteration=u'h', order=5)
# vau:http://en.wikipedia.org/wiki/
data['waw'] = dict(letter=[u'𐤅‬'], name=u'𐤅‬', segment='vowel', subsegment='', transliteration=u'w', order=6)
# zayin:http://en.wiktionary.org/wiki/
data['zayin'] = dict(letter=[u'𐤆'], name=u'𐤆', segment='consonant', subsegment='', transliteration=u'z', order=7)
# heth:http://en.wiktionary.org/wiki/
data['het'] = dict(letter=[u'𐤇'], name=u'𐤇', segment='consonant', subsegment='', transliteration=u'ḥ', order=8)
# teth:http://en.wiktionary.org/wiki/
data['tet'] = dict(letter=[u'𐤈'], name=u'𐤈', segment='consonant', subsegment='', transliteration=u'ṭ', order=9)

# letters from 𐤉 to 𐤑‬
# yod:http://en.wiktionary.org/wiki/
data['yod'] = dict(letter=[u'𐤉'], name=u'𐤉', segment='vowel', subsegment='', transliteration=u'y', order=10)
# kaph:http://en.wiktionary.org/wiki/
data['kap'] = dict(letter=[u'𐤊‬'], name=u'𐤊‬', segment='consonant', subsegment='', transliteration=u'k', order=11)
# lamed:http://en.wiktionary.org/wiki/
data['lamed'] = dict(letter=[u'𐤋'], name=u'𐤋', segment='consonant', subsegment='', transliteration=u'l', order=12)
# mem:http://en.wiktionary.org/wiki/
data['mem'] = dict(letter=[u'𐤌‬'], name=u'𐤌‬', segment='consonant', subsegment='', transliteration=u'm', order=13)
# num:http://en.wiktionary.org/wiki/
data['nun'] = dict(letter=[u'𐤍'], name=u'𐤍', segment='consonant', subsegment='', transliteration=u'n', order=14)
# samekh:http://en.wiktionary.org/wiki/
data['semek'] = dict(letter=[u'𐤎‬'], name=u'𐤎‬', segment='consonant', subsegment='', transliteration=u's', order=15)
# ayin:http://en.wiktionary.org/wiki/
data['ayin'] = dict(letter=[u'𐤏‬'], name=u'𐤏‬', segment='vowel', subsegment='', transliteration=u'o', order=16)
# pe:http://en.wiktionary.org/wiki/
data['pe'] = dict(letter=[u'𐤐'], name=u'𐤐', segment='consonant', subsegment='', transliteration=u'p', order=17)
# tsade:http://en.wikipedia.org/wiki/
data['sade'] = dict(letter=[u'𐤑‬'], name=u'𐤑‬', segment='consonant', subsegment='', transliteration=u'ṣ', order=18)

# letters from 𐤒 to ܬ
# resh:http://en.wiktionary.org/wiki/
data['qop'] = dict(letter=[u'𐤒'], name=u'𐤒', segment='consonant', subsegment='', transliteration=u'q', order=19)
# shin:http://en.wiktionary.org/wiki/
data['res'] = dict(letter=[u'𐤓'], name=u'𐤓', segment='consonant', subsegment='', transliteration=u'r', order=20)
# tau:http://en.wiktionary.org/wiki/
data['sin'] = dict(letter=[u'𐤔'], name=u'𐤔', segment='consonant', subsegment='', transliteration=u'š', order=21)
# final_tsade:http://en.wiktionary.org/wiki/
data['taw'] = dict(letter=[u'𐤕'], name=u'𐤕', segment='consonant', subsegment='', transliteration=u't', order=22)
# final_kaph:http://en.wiktionary.org/wiki/
#data['final_kap'] = dict(letter=[u'ⲫ'], name=u'ⲫ', segment='consonant', subsegment='', transliteration=u'K', order=23)
# final_mem, chi:http://en.wiktionⲣary.org/wiki/
#data['final_mem'] = dict(letter=[u'ⲭ'], name=u'ⲭ', segment='consonant', subsegment='', transliteration=u'M', order=24)
# final_nun:http://en.wiktionary.org/wiki/
#data['final_nun'] = dict(letter=[u'ⲯ'], name=u'ⲯ', segment='consonant', subsegment='', transliteration=u'N', order=25)
# final_pe:http://en.wiktionary.org/wiki/
#data['final_pe'] = dict(letter=[u'ⲱ'], name=u'ⲱ', segment='consonant', subsegment='', transliteration=u'P', order=26)
# final_tsade:http://en.wiktionary.org/wiki/
#data['final_sadhe'] = dict(letter=[u'ⳁ'], name=u'ⳁ', segment='consonant', subsegment='', transliteration=u'Y', order=27)

r = romanizer(data, False)

# collect phoenician and transliteration letters from data dictionary for preprocessing function
letters = ''.join([''.join(d['letter'])+d['transliteration'] for key, d in data.items()])
regex = re.compile('[^%s ]+' % letters)
regex2 = re.compile('[^%s\s]' % ''.join([''.join(d['letter']) for key, d in data.items()]))

r = romanizer(data)

def filter(string):
    """
    Preprocess string to remove all other characters but phoenician ones

    :param string:
    :return:
    """
    # remove all unwanted characters
    return regex2.sub(' ', string)

def preprocess(string):
    """
    Preprocess string to transform all diacritics and remove other special characters

    :param string:
    :return:
    """
    return regex.sub('', string)

def convert(string, sanitize=False):
    """
    Swap characters from script to transliterated version and vice versa.
    Optionally sanitize string by using preprocess function.

    :param sanitize:
    :param string:
    :return:
    """
    return r.convert(string, (preprocess if sanitize else False))



#!/usr/local/bin/python
# -*- coding: utf-8 -*-
# file: arm.py

import re
from collections import OrderedDict
from .romanizer import romanizer

has_capitals = False

data = OrderedDict()

# https://en.wikipedia.org/wiki/Aramaic_alphabet

# letters from 𐡀 to 𐡈
# alef:http://en.wiktionary.org/wiki/
data['alap'] = dict(letter=[u'𐡀'], name=u'𐡀', segment='vowel', subsegment='', transliteration=u'a', order=1)
# beth:http://en.wiktionary.org/wiki/
data['beth'] = dict(letter=[u'𐡁‬'], name=u'𐡁‬', segment='consonant', subsegment='', transliteration=u'b', order=2)
# gimel:http://en.wiktionary.org/wiki/
data['gamal'] = dict(letter=[u'𐡂'], name=u'𐡂', segment='consonant', subsegment='', transliteration=u'g', order=3)
# daleth:http://en.wiktionary.org/wiki/
data['dalath'] = dict(letter=[u'𐡃‬'], name=u'𐡃‬', segment='consonant', subsegment='', transliteration=u'd', order=4)
# he:http://en.wiktionary.org/wiki/
data['he'] = dict(letter=[u'𐡄'], name=u'𐡄', segment='vowel', subsegment='', transliteration=u'h', order=5)
# vau:http://en.wikipedia.org/wiki/
data['waw'] = dict(letter=[u'𐡅‬'], name=u'𐡅‬', segment='vowel', subsegment='', transliteration=u'w', order=6)
# zayin:http://en.wiktionary.org/wiki/
data['zain'] = dict(letter=[u'𐡆‬'], name=u'𐡆‬', segment='consonant', subsegment='', transliteration=u'z', order=7)
# heth:http://en.wiktionary.org/wiki/
data['heth'] = dict(letter=[u'𐡇‬'], name=u'𐡇‬', segment='consonant', subsegment='', transliteration=u'ḥ', order=8)
# teth:http://en.wiktionary.org/wiki/
data['teth'] = dict(letter=[u'𐡈'], name=u'𐡈', segment='consonant', subsegment='', transliteration=u'ṭ', order=9)

# letters from 𐡉 to 𐡑‬
# yod:http://en.wiktionary.org/wiki/
data['yodh'] = dict(letter=[u'𐡉'], name=u'𐡉', segment='vowel', subsegment='', transliteration=u'i', order=10)
# kaph:http://en.wiktionary.org/wiki/
data['kap'] = dict(letter=[u'𐡊'], name=u'𐡊', segment='consonant', subsegment='', transliteration=u'k', order=11)
# lamed:http://en.wiktionary.org/wiki/
data['lamadh'] = dict(letter=[u'𐡋'], name=u'𐡋', segment='consonant', subsegment='', transliteration=u'l', order=12)
# mem:http://en.wiktionary.org/wiki/
data['mem'] = dict(letter=[u'𐡌'], name=u'𐡌', segment='consonant', subsegment='', transliteration=u'm', order=13)
# num:http://en.wiktionary.org/wiki/
data['num'] = dict(letter=[u'𐡍‬'], name=u'𐡍‬', segment='consonant', subsegment='', transliteration=u'n', order=14)
# samekh:http://en.wiktionary.org/wiki/
data['semkath'] = dict(letter=[u'𐡎'], name=u'𐡎', segment='consonant', subsegment='', transliteration=u's', order=15)
# ayin:http://en.wiktionary.org/wiki/
data['e'] = dict(letter=[u'𐡏‬'], name=u'𐡏‬', segment='vowel', subsegment='', transliteration=u'o', order=16)
# pe:http://en.wiktionary.org/wiki/
data['pe'] = dict(letter=[u'𐡐'], name=u'𐡐', segment='consonant', subsegment='', transliteration=u'p', order=17)
# tsade:http://en.wikipedia.org/wiki/
data['sadhe'] = dict(letter=[u'𐡑‬'], name=u'𐡑‬', segment='consonant', subsegment='', transliteration=u'ṣ', order=18)

# letters from 𐡒 to 𐡕
# resh:http://en.wiktionary.org/wiki/
data['qop'] = dict(letter=[u'𐡒'], name=u'𐡒', segment='consonant', subsegment='', transliteration=u'q', order=19)
# shin:http://en.wiktionary.org/wiki/
data['resh'] = dict(letter=[u'𐡓'], name=u'𐡓', segment='consonant', subsegment='', transliteration=u'r', order=20)
# tau:http://en.wiktionary.org/wiki/
data['shin'] = dict(letter=[u'𐡔'], name=u'𐡔', segment='consonant', subsegment='', transliteration=u'š', order=21)
# final_tsade:http://en.wiktionary.org/wiki/
data['taw'] = dict(letter=[u'𐡕'], name=u'𐡕', segment='consonant', subsegment='', transliteration=u't', order=22)
# final_kaph:http://en.wiktionary.org/wiki/
#data['final_kap'] = dict(letter=[u'ⲫ'], name=u'ⲫ', segment='consonant', subsegment='', transliteration=u'K', order=23)
# final_mem, chi:http://en.wiktionⲣary.org/wiki/
#data['final_mem'] = dict(letter=[u'ⲭ'], name=u'ⲭ', segment='consonant', subsegment='', transliteration=u'M', order=24)
# final_nun:http://en.wiktionary.org/wiki/
#data['final_nun'] = dict(letter=[u'ⲯ'], name=u'ⲯ', segment='consonant', subsegment='', transliteration=u'N', order=25)
# final_pe:http://en.wiktionary.org/wiki/
#data['final_pe'] = dict(letter=[u'ⲱ'], name=u'ⲱ', segment='consonant', subsegment='', transliteration=u'P', order=26)
# final_tsade:http://en.wiktionary.org/wiki/
#data['final_sadhe'] = dict(letter=[u'ⳁ'], name=u'ⳁ', segment='consonant', subsegment='', transliteration=u'Y', order=27)

r = romanizer(data, False)

# collect aramaic and transliteration letters from data dictionary for preprocessing function
letters = ''.join([''.join(d['letter'])+d['transliteration'] for key, d in data.items()])
regex = re.compile('[^%s ]+' % letters)
regex2 = re.compile('[^%s\s]' % ''.join([''.join(d['letter']) for key, d in data.items()]))

r = romanizer(data)

def filter(string):
    """
    Preprocess string to remove all other characters but aramaic ones

    :param string:
    :return:
    """
    # remove all unwanted characters
    return regex2.sub(' ', string)

def preprocess(string):
    """
    Preprocess string to transform all diacritics and remove other special characters

    :param string:
    :return:
    """
    return regex.sub('', string)

def convert(string, sanitize=False):
    """
    Swap characters from script to transliterated version and vice versa.
    Optionally sanitize string by using preprocess function.

    :param sanitize:
    :param string:
    :return:
    """
    return r.convert(string, (preprocess if sanitize else False))



#!/usr/local/bin/python
# -*- coding: utf-8 -*-
# file: cop.py

import re
from collections import OrderedDict
from .romanizer import romanizer

has_capitals = True

data = OrderedDict()

# http://en.wikipedia.org/wiki/Coptic_alphabet

# letters from ⲁ to ⲑ (1 - 9)
# alef:http://en.wiktionary.org/wiki/
data['alpha'] = dict(letter=[u'ⲁ'], name=u'ⲁ', segment='vowel', subsegment='', transliteration=u'a', order=1)
# beth:http://en.wiktionary.org/wiki/
data['beth'] = dict(letter=[u'ⲃ'], name=u'ⲃ', segment='consonant', subsegment='', transliteration=u'b', order=2)
# gimel:http://en.wiktionary.org/wiki/
data['gamma'] = dict(letter=[u'ⲅ'], name=u'ⲅ', segment='consonant', subsegment='', transliteration=u'g', order=3)
# daleth:http://en.wiktionary.org/wiki/
data['delta'] = dict(letter=[u'ⲇ'], name=u'ⲇ', segment='consonant', subsegment='', transliteration=u'd', order=4)
# he:http://en.wiktionary.org/wiki/
data['ei'] = dict(letter=[u'ⲉ'], name=u'ⲉי', segment='vowel', subsegment='', transliteration=u'e', order=5)
# vau:http://en.wikipedia.org/wiki/
data['so'] = dict(letter=[u'ⲋ'], name=u'ⲋ', segment='numeral', subsegment='', transliteration=u'w', order=6)
# zayin:http://en.wiktionary.org/wiki/
data['zeta'] = dict(letter=[u'ⲍ'], name=u'ⲍ', segment='consonant', subsegment='', transliteration=u'z', order=7)
# heth:http://en.wiktionary.org/wiki/
data['eta'] = dict(letter=[u'ⲏ'], name=u'ⲏ', segment='vowel', subsegment='', transliteration=u'ê', order=8)
# teth:http://en.wiktionary.org/wiki/
data['theta'] = dict(letter=[u'ⲑ'], name=u'ⲑ', segment='consonant', subsegment='', transliteration=u'h', order=9)

# letters from י to ϥ (10 - 90)
# yod:http://en.wiktionary.org/wiki/
data['yota'] = dict(letter=[u'ⲓ'], name=u'ⲓ', segment='vowel', subsegment='', transliteration=u'i', order=10)
# kaph:http://en.wiktionary.org/wiki/
data['kappa'] = dict(letter=[u'ⲕ'], name=u'ⲕ', segment='consonant', subsegment='', transliteration=u'k', order=11)
# lamed:http://en.wiktionary.org/wiki/
data['lambda'] = dict(letter=[u'ⲗ'], name=u'ⲗ', segment='consonant', subsegment='', transliteration=u'l', order=12)
# mem:http://en.wiktionary.org/wiki/
data['me'] = dict(letter=[u'ⲙ'], name=u'ⲙ', segment='consonant', subsegment='', transliteration=u'm', order=13)
# num:http://en.wiktionary.org/wiki/
data['ne'] = dict(letter=[u'ⲛ'], name=u'ⲛ', segment='consonant', subsegment='', transliteration=u'n', order=14)
# samekh:http://en.wiktionary.org/wiki/
data['eksi'] = dict(letter=[u'ⲝ'], name=u'ⲝ', segment='consonant', subsegment='', transliteration=u'x', order=15)
# ayin:http://en.wiktionary.org/wiki/
data['o'] = dict(letter=[u'ⲟ'], name=u'ⲟ', segment='consonant', subsegment='', transliteration=u'o', order=16)
# pe:http://en.wiktionary.org/wiki/
data['pi'] = dict(letter=[u'ⲡ'], name=u'ⲡ', segment='consonant', subsegment='', transliteration=u'p', order=17)
# tsade:http://en.wikipedia.org/wiki/
data['fay'] = dict(letter=[u'ϥ'], name=u'ϥ', segment='numeral', subsegment='', transliteration=u'q', order=18)

# letters from ⲣ to ⳁ (100 - 900)
# resh:http://en.wiktionary.org/wiki/
data['ro'] = dict(letter=[u'ⲣ'], name=u'ⲣ', segment='consonant', subsegment='', transliteration=u'r', order=19)
# shin:http://en.wiktionary.org/wiki/
data['sima'] = dict(letter=[u'ⲥ'], name=u'ⲥ', segment='consonant', subsegment='', transliteration=u's', order=20)
# tau:http://en.wiktionary.org/wiki/
data['taw'] = dict(letter=[u'ⲧ'], name=u'ⲧו', segment='consonant', subsegment='', transliteration=u't', order=21)
# final_tsade:http://en.wiktionary.org/wiki/Tsade
data['epsilon'] = dict(letter=[u'ⲩ'], name=u'ⲩ', segment='vowel', subsegment='', transliteration=u'u', order=22)
# final_kaph:http://en.wiktionary.org/wiki/
data['fi'] = dict(letter=[u'ⲫ'], name=u'ⲫ', segment='consonant', subsegment='', transliteration=u'f', order=23)
# final_mem, chi:http://en.wiktionⲣary.org/wiki/
data['khe'] = dict(letter=[u'ⲭ'], name=u'ⲭ', segment='consonant', subsegment='', transliteration=u'c', order=24)
# final_nun:http://en.wiktionary.org/wiki/
data['epsi'] = dict(letter=[u'ⲯ'], name=u'ⲯ', segment='consonant', subsegment='', transliteration=u'y', order=25)
# final_pe:http://en.wiktionary.org/wiki/
data['ou'] = dict(letter=[u'ⲱ'], name=u'ⲱ', segment='vowel', subsegment='', transliteration=u'ô', order=26)
# final_tsade:http://en.wiktionary.org/wiki/Tsade
data['nine'] = dict(letter=[u'ⳁ'], name=u'ⳁ', segment='numeral', subsegment='', transliteration=u'j', order=27)

r = romanizer(data, False)

# collect coptic and transliteration letters from data dictionary for preprocessing function
letters = ''.join([''.join(d['letter'])+d['transliteration']+''.join(d['letter']).upper()+d['transliteration'].upper() for key, d in data.items()])
regex = re.compile('[^%s ]+' % letters)
regex2 = re.compile('[^%s\s]' % ''.join([''.join(d['letter'])+''.join(d['letter']).upper() for key, d in data.items()]))

r = romanizer(data)

def filter(string):
    """
    Preprocess string to remove all other characters but coptic ones

    :param string:
    :return:
    """
    # remove all unwanted characters
    return regex2.sub(' ', string)

def preprocess(string):
    """
    Preprocess string to transform all diacritics and remove other special characters

    :param string:
    :return:
    """
    return regex.sub('', string)

def convert(string, sanitize=False):
    """
    Swap characters from script to transliterated version and vice versa.
    Optionally sanitize string by using preprocess function.

    :param sanitize:
    :param string:
    :return:
    """
    return r.convert(string, (preprocess if sanitize else False))



#!/usr/local/bin/python
# -*- coding: utf-8 -*-
# file: eng.py

import re
from collections import OrderedDict
from .romanizer import romanizer

has_capitals = True

data = OrderedDict()

data['a'] = dict(letter=[u'a'], name=u'a', segment='vowel',     subsegment='short', transliteration=u'a', order=1)
data['b'] = dict(letter=[u'b'], name=u'b', segment='consonant', subsegment='mute', transliteration=u'b', order=2)
data['c'] = dict(letter=[u'c'], name=u'c', segment='consonant', subsegment='mute', transliteration=u'c', order=3)
data['d'] = dict(letter=[u'd'], name=u'd', segment='consonant', subsegment='mute', transliteration=u'd', order=4)
data['e'] = dict(letter=[u'e'], name=u'e', segment='vowel',     subsegment='short', transliteration=u'e', order=5)
data['f'] = dict(letter=[u'f'], name=u'f', segment='consonant', subsegment='mute', transliteration=u'f', order=6)
data['g'] = dict(letter=[u'g'], name=u'g', segment='consonant', subsegment='mute', transliteration=u'g', order=7)
data['h'] = dict(letter=[u'h'], name=u'h', segment='consonant', subsegment='mute', transliteration=u'h', order=8)
data['i'] = dict(letter=[u'i'], name=u'i', segment='vowel',     subsegment='short', transliteration=u'i', order=9)
data['j'] = dict(letter=[u'j'], name=u'j', segment='consonant', subsegment='mute', transliteration=u'j', order=10)
data['k'] = dict(letter=[u'k'], name=u'k', segment='consonant', subsegment='mute', transliteration=u'k', order=11)
data['l'] = dict(letter=[u'l'], name=u'l', segment='consonant', subsegment='mute', transliteration=u'l', order=12)
data['m'] = dict(letter=[u'm'], name=u'm', segment='consonant', subsegment='mute', transliteration=u'm', order=13)
data['n'] = dict(letter=[u'n'], name=u'n', segment='consonant', subsegment='mute', transliteration=u'n', order=14)
data['o'] = dict(letter=[u'o'], name=u'o', segment='vowel',     subsegment='short', transliteration=u'o', order=15)
data['p'] = dict(letter=[u'p'], name=u'p', segment='consonant', subsegment='mute', transliteration=u'p', order=16)
data['q'] = dict(letter=[u'q'], name=u'q', segment='consonant', subsegment='mute', transliteration=u'q', order=17)
data['r'] = dict(letter=[u'r'], name=u'r', segment='consonant', subsegment='mute', transliteration=u'r', order=18)
data['s'] = dict(letter=[u's'], name=u's', segment='consonant', subsegment='mute', transliteration=u's', order=19)
data['t'] = dict(letter=[u't'], name=u't', segment='consonant', subsegment='mute', transliteration=u't', order=20)
data['u'] = dict(letter=[u'u'], name=u'u', segment='vowel',     subsegment='short', transliteration=u'u', order=21)
data['v'] = dict(letter=[u'v'], name=u'v', segment='consonant', subsegment='mute', transliteration=u'v', order=22)
data['w'] = dict(letter=[u'w'], name=u'w', segment='consonant', subsegment='mute', transliteration=u'w', order=23)
data['x'] = dict(letter=[u'x'], name=u'x', segment='consonant', subsegment='mute', transliteration=u'x', order=24)
data['y'] = dict(letter=[u'y'], name=u'y', segment='vowel',     subsegment='short', transliteration=u'y', order=25)
data['z'] = dict(letter=[u'z'], name=u'z', segment='consonant', subsegment='mute', transliteration=u'z', order=26)

r = romanizer(data)

# collect letters from data dictionary for preprocessing function
letters = ''.join(data.keys())
regex = re.compile('[^%s ]+' % letters)

def filter(string):
    """
    Preprocess string to remove all other characters but english ones

    :param string:
    :return:
    """
    # remove all unwanted characters
    return string

def preprocess(string):
    """
    Preprocess string to transform all diacritics and remove other special characters

    :param string:
    :return:
    """
    return regex.sub('', string)

def convert(string, sanitize=False):
    """
    Swap characters from script to transliterated version and vice versa.
    Optionally sanitize string by using preprocess function.

    :param sanitize:
    :param string:
    :return:
    """
    return r.convert(string, (preprocess if sanitize else False))



#!/usr/local/bin/python
# -*- coding: utf-8 -*-
# file: romanizer.py

import re

class romanizer(object):

    def __init__(self, data, add_uppercase = True):
        self.substitutes = {}
        for key, d in data.items():
            # add transliteration letter substituting greek letters
            for x in d['letter']:
                self.substitutes[x] = d['transliteration']
                if add_uppercase:
                    self.substitutes[x.upper()] = d['transliteration'].upper()
            # add the primary greek letter substituting transliteration letter
            self.substitutes[d['transliteration']] = d['letter'][0]
            if add_uppercase:
                self.substitutes[d['transliteration'].upper()] = d['letter'][0].upper()

        if len(self.substitutes):
            self.regex = re.compile('|'.join(self.substitutes.keys()))

    def filter(self):
        pass

    def preprocess(self):
        pass

    def convert(self, string, preprocess = None):
        """
        Swap characters from a script to transliteration and vice versa.
        Optionally sanitize string by using preprocess function.

        :param preprocess:
        :param string:
        :return:
        """
        string = preprocess(string) if preprocess else string
        if self.regex:
            return self.regex.sub(lambda x: self.substitutes[x.group()], string)
        else:
            return string



#!/usr/local/bin/python
# -*- coding: utf-8 -*-
# file: grc.py

import re
from collections import OrderedDict
from .romanizer import romanizer

has_capitals = True

data = OrderedDict()

"""

Data mapping between greek letters and their linguistic components

Resources:

- http://en.wikipedia.org/wiki/Greek_alphabet
- http://www.chlt.org/FirstGreekBook/JWW_FGB1.html
- http://www.webtopos.gr/eng/languages/greek/alphabet/alpha.htm
- http://www.class.uh.edu/mcl/faculty/pozzi/grnl1/intr/0.2.1.pract.vow.htm
- http://en.wikipedia.org/wiki/transliterationization_of_Greek
- http://en.citizendium.org/wiki/greek_alphabet

Segments:
- vowel
- consonant
- numeral (only)

Subsegments:
- semivowel (liquid, siblant and γ-nasal not specified on data table)
- double
- mute

Mutes (not specified on data table):

{class-order} {letter}

labial-smooth π
labial-middle β
labial-rought φ

palatal-smooth κ
palatal-middle γ
palatal-rought χ

lingual-smooth τ
lingual-middle δ
lingual-rought θ

Seven vowels: α ε η ι ο υ ω (a e ê i o u ô)

Numerals only: ϛ ϙ ϡ (6, 90, 900 or w, q, j)

"""

# letters from α to θ (1 to 9)
# alpha:http://en.wiktionary.org/wiki/ἄλφα
data['alpha'] = dict(letter=[u'α'], name=u'αλφα', segment='vowel', subsegment='short', transliteration=u'a', order=1)
# beta:http://en.wiktionary.org/wiki/βῆτα
data['beta'] = dict(letter=[u'β'], name=u'βητα', segment='consonant', subsegment='mute', transliteration=u'b', order=2)
# gamma:http://en.wiktionary.org/wiki/γάμμα
data['gamma'] = dict(letter=[u'γ'], name=u'γαμμα', segment='consonant', subsegment='mute', transliteration=u'g', order=3)
# delta:http://en.wiktionary.org/wiki/δέλτα
data['delta'] = dict(letter=[u'δ'], name=u'δελτα', segment='consonant', subsegment='mute', transliteration=u'd', order=4)
# epsilon:http://en.wiktionary.org/wiki/epsilon
data['epsilon'] = dict(letter=[u'ε', u'ϵ'], name=u'ε ψιλον', segment='vowel', subsegment='short', transliteration=u'e', order=5)
# digamma/stigma/episemon/wau:http://en.wikipedia.org/wiki/Digamma
data['digamma'] = dict(letter=[u'ϛ', u'ϝ'], name=u'διγαμμα', segment='numeral', subsegment='', transliteration=u'w', order=6)
#data['stigma'] = dict(letter=[u'ϛ'], name=u'στιγμα', segment='numeral', transliteration=u'w')
# zeta:http://en.wiktionary.org/wiki/ζῆτα
data['zeta'] = dict(letter=[u'ζ'], name=u'ζητα', segment='consonant', subsegment='double', transliteration=u'z', order=7)
# eta:http://en.wiktionary.org/wiki/ἦτα
data['eta'] = dict(letter=[u'η'], name=u'ητα', segment='vowel', subsegment='long', transliteration=u'ê', order=8)
# theta:http://en.wiktionary.org/wiki/θῆτα
data['theta'] = dict(letter=[u'θ', u'ϑ'], name=u'θητα', segment='consonant', subsegment='mute', transliteration=u'h', order=9)

# letters from ι to ϙ (10 to 90)
# iota:http://en.wiktionary.org/wiki/ἰῶτα
data['iota'] = dict(letter=[u'ι'], name=u'ιωτα', segment='vowel', subsegment='short', transliteration=u'i', order=10)
# kappa:http://en.wiktionary.org/wiki/κάππα
data['kappa'] = dict(letter=[u'κ'], name=u'καππα', segment='consonant', subsegment='mute', transliteration=u'k', order=11)
# lambda:http://en.wiktionary.org/wiki/λάμβδα
data['lambda'] = dict(letter=[u'λ'], name=u'λαμβδα', segment='consonant', subsegment='semivowel', transliteration=u'l', order=12)
# mu:http://en.wiktionary.org/wiki/mu
data['mu'] = dict(letter=[u'μ'], name=u'μυ', segment='consonant', subsegment='semivowel', transliteration=u'm', order=13)
# nu:http://en.wiktionary.org/wiki/νῦ
data['nu'] = dict(letter=[u'ν'], name=u'νυ', segment='consonant', subsegment='semivowel', transliteration=u'n', order=14)
# xi:http://en.wiktionary.org/wiki/ξεῖ
data['xi'] = dict(letter=[u'ξ'], name=u'ξει', segment='consonant', subsegment='double', transliteration=u'c', order=15)
# omicron:http://en.wiktionary.org/wiki/omicron
data['omicron'] = dict(letter=[u'ο'], name=u'ο μικρον', segment='vowel', subsegment='short', transliteration=u'o', order=16)
# pi:http://en.wiktionary.org/wiki/πεῖ
data['pi'] = dict(letter=[u'π'], name=u'πει', segment='consonant', subsegment='mute', transliteration=u'p', order=17)
# koppa:http://en.wikipedia.org/wiki/Koppa_(letter)
# http://www.webtopos.gr/eng/languages/greek/alphabet/earlyletters.htm
data['qoppa'] = dict(letter=[u'ϙ', u'ϟ'], name=u'κοππα', segment='numeral', subsegment='', transliteration=u'q', order=18)

# letters from ρ to ϡ (100 to 900)
# rho:http://en.wiktionary.org/wiki/ῥῶ
data['rho'] = dict(letter=[u'ρ'], name=u'ρω', segment='consonant', subsegment='semivowel', transliteration=u'r', order=19)
# sigma:http://en.wiktionary.org/wiki/σίγμα
data['sigma'] = dict(letter=[u'σ', u'ϲ', u'ς'], name=u'σιγμα', segment='consonant', subsegment='semivowel', transliteration=u's', order=20)
#data['san'] = dict(letter=[u'ϻ'], name=u'σαν', segment='consonant', subsegment='semivowel', transliteration=u's')
# tau:http://en.wiktionary.org/wiki/tau
data['tau'] = dict(letter=[u'τ'], name=u'ταυ', segment='consonant', subsegment='mute', transliteration=u't', order=21)
# upsilon:http://en.wiktionary.org/wiki/upsilon
data['upsilon'] = dict(letter=[u'υ', u'ϒ'], name=u'υ ψιλον', segment='vowel', subsegment='short', transliteration=u'u', order=22)
# phi:http://en.wiktionary.org/wiki/phi
data['phi'] = dict(letter=[u'φ'], name=u'φει', segment='consonant', subsegment='mute', transliteration=u'f', order=23)
# khi, chi:http://en.wiktionary.org/wiki/chi
data['chi'] = dict(letter=[u'χ'], name=u'χει', segment='consonant', subsegment='mute', transliteration=u'x', order=24)
# psi:http://en.wiktionary.org/wiki/psi
data['psi'] = dict(letter=[u'ψ'], name=u'ψει', segment='consonant', subsegment='double', transliteration=u'y', order=25)
# omega:http://en.wiktionary.org/wiki/omega
data['omega'] = dict(letter=[u'ω'], name=u'ω μεγα', segment='vowel', subsegment='long', transliteration=u'ô', order=26)
# sampi/disigma
# http://en.wikipedia.org/wiki/Sampi
# http://www.tlg.uci.edu/~opoudjis/unicode/other_nonattic.html#sampi
# http://www.parthia.com/fonts/sampi.htm
# http://www.jstor.org/stable/636031
data['sampi'] = dict(letter=[u'ϡ', u'ͳ'], name=u'σαμπι', segment='numeral', subsegment='', transliteration=u'j', order=27)
#data['disigma'] = dict(letter=[u'ϡ'], name=u'δισιγμα', segment='numeral', subsegment='', transliteration=u'j')

data['alpha_m'] = dict(letter=[u'ạ'], name=u'σαμπι', segment='numeral', subsegment='', transliteration=u'ạ', order=28)
# beta:http://en.wiktionary.org/wiki/βῆτα
data['beta_m'] = dict(letter=[u'ḅ'], name=u'βητα', segment='numeral', subsegment='', transliteration=u'ḅ', order=29)
# gamma:http://en.wiktionary.org/wiki/γάμμα
data['gamma_m'] = dict(letter=[u'ġ'], name=u'γαμμα', segment='numeral', subsegment='', transliteration=u'ġ', order=30)
# delta:http://en.wiktionary.org/wiki/δέλτα
data['delta_m'] = dict(letter=[u'ḍ'], name=u'δελτα', segment='numeral', subsegment='', transliteration=u'ḍ', order=31)
# epsilon:http://en.wiktionary.org/wiki/epsilon
data['epsilon_m'] = dict(letter=[u'ė'], name=u'ε ψιλον', segment='numeral', subsegment='', transliteration=u'ė', order=32)
# digamma/stigma/episemon/wau:http://en.wikipedia.org/wiki/Digamma
data['digamma_m'] = dict(letter=[u'ċ'], name=u'διγαμμα', segment='numeral', subsegment='', transliteration=u'ċ', order=33)
# zeta:http://en.wiktionary.org/wiki/ζῆτα
data['zeta_m'] = dict(letter=[u'ị'], name=u'ζητα', segment='numeral', subsegment='', transliteration=u'ị', order=34)
# eta:http://en.wiktionary.org/wiki/ἦτα
data['eta_m'] = dict(letter=[u'ḥ'], name=u'ητα', segment='numeral', subsegment='', transliteration=u'ḥ', order=35)
# theta:http://en.wiktionary.org/wiki/θῆτα
data['theta_m'] = dict(letter=[u'ṭ'], name=u'θητα', segment='numeral', subsegment='', transliteration=u'ṭ', order=36)

data['mu_m'] = dict(letter=[u'ṃ'], name=u'θητα', segment='numeral', subsegment='', transliteration=u'ṃ', order=37)


r = romanizer(data)

# accents / diacritics for simplified greek letters

_accents_ = {}

_accents_[u'Α'] = u"ᾏ Ἂ ᾈ Ἇ ᾊ Ἅ Ἀ Ἃ ᾉ Ὰ ᾋ Ἄ Ά Ἁ ᾼ ᾎ ᾌ ᾍ Ἆ Ᾰ Ᾱ Ά"
_accents_[u'α'] = u"ἄ ἂ ᾀ ᾷ ἁ ὰ ᾴ ἀ ἇ ᾄ ἅ ά ᾂ ᾆ ἆ ᾳ ᾲ ᾅ ᾃ ᾶ ᾁ ᾇ ἃ ά ᾰ ᾱ"

_accents_[u'Ε'] = u"Έ Ἑ Ἕ Ἓ Ὲ Ἐ Ἔ Ἒ Έ"
_accents_[u'ε'] = u"έ ἐ ὲ ἑ ἒ ἓ ἔ ἕ έ"

_accents_[u'Η'] = u"ᾚ ᾞ Ἠ Ἤ Ἢ Ἦ Ή Ἡ Ἥ Ἣ Ἧ Ὴ ῌ ᾙ ᾝ ᾛ ᾟ ᾘ ᾜ Ή"
_accents_[u'η'] = u"ᾖ ῇ ῄ ᾑ ἠ ἧ ἦ ἤ ᾐ ῂ ῃ ἣ ὴ ή ῆ ᾕ ᾓ ἥ ἢ ᾔ ᾗ ἡ ᾒ ή"

_accents_[u'Ι'] = u"Ὶ Ἶ Ἵ Ί Ἰ Ἱ Ἲ Ἴ Ἳ Ἷ Ί Ῑ Ῐ"
_accents_[u'ι'] = u"î ἴ ἰ ἵ ῒ ἲ ί ῗ ἱ ἳ ϊ ὶ ΐ ἷ ῖ ì ἶ ῐ ῑ ΐ ί"

_accents_[u'Ο'] = u"Ό Ὁ Ὅ Ὃ Ὸ Ὀ Ὄ Ὂ Ό"
_accents_[u'ο'] = u"ὁ ὂ ὀ ó ò ὅ ὄ ὃ ό ὸ ό"

_accents_[u'Ρ'] = u"Ῥ"
_accents_[u'ρ'] = u"ῥ ῤ"

_accents_[u'ϒ'] = u"Ύ Ὑ Ὕ Ὓ Ὗ Ὺ Ῡ Ύ Ῠ"
_accents_[u'υ'] = u"ῡ ΰ ῠ ῢ ὑ ὒ ὗ ὕ ύ ῦ ὐ ù ϋ ὺ ὓ ὖ ῧ ὔ ΰ ύ"

_accents_[u'Ω'] = u"ᾪ ᾮ Ὠ Ὤ Ὢ Ὦ Ώ Ὡ Ὥ Ὣ Ὧ Ὼ ῼ ᾩ ᾭ ᾫ ᾯ ᾨ ᾬ Ώ"
_accents_[u'ω'] = u"ῳ ᾧ ὥ ῷ ᾡ ὤ ᾦ ᾥ ῴ ᾢ ᾣ ᾤ ὣ ώ ῶ ὡ ᾠ ὢ ὦ ῲ ὼ ὠ ὧ ώ"

accents = {}

for letter, values in _accents_.items():
    for value in values.split():
        accents[value] = letter

regex1 = re.compile('|'.join(accents.keys()))
# collect greek and transliteration letters from data dictionary
letters = ''.join([''.join(d['letter'])+\
          ''.join(d['letter']).upper()+\
          d['transliteration']+\
          d['transliteration'].upper() for key, d in data.items()])
regex2 = re.compile('[^%s ]+' % letters)

regex3 = re.compile('[^%s%s\s]' % (''.join(accents.keys()), "ΑαΒβΓγΔδΕεϵΖζΗηΘθϑΙιΚκΛλΜμΝνΞξΟοΠπΡρΣϹσϲςΤτΥυϒΦφΧχΨψΩωϚϜϛϝϞϘϟϙϠͲϡͳ"))

def deaccent(string):
    """
    Remove diacritics (accents), keep base forms of Greek letters

    :param string:
    :return:
    """
    # convert diacritics to simpler forms
    return regex1.sub(lambda x: accents[x.group()], string)

def filter(string):
    """
    Preprocess string to remove all other characters but Greek ones and whitespace

    :param string:
    :return:
    """
    # remove all unwanted characters by replacing them with empty space
    # if removing all other characters then word divisioning might get lost and further
    # processing text would get difficult if not impossible
    return regex3.sub(' ', string)

def preprocess(string):
    """
    Preprocess string to transform all diacritics and remove other special characters than appropriate

    :param string:
    :return:
    """
    # convert diacritics to simpler forms
    string = regex1.sub(lambda x: accents[x.group()], string)
    # remove all rest of the unwanted characters
    return regex2.sub('', string)

def convert(string, sanitize=False):
    """
    Swap characters from script to transliterated version and vice versa.
    Optionally sanitize string by using preprocess function.

    :param sanitize:
    :param string:
    :return:
    """
    return r.convert(string, (preprocess if sanitize else False))



try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup
import os

# python setup.py sdist upload
# pip install --no-cache-dir --upgrade romanize3

version = 'v0.1.12'

name = 'romanize3'

def read(fname):
    try:
        return open(os.path.join(os.path.dirname(__file__), fname), encoding="utf8").read()
    except:
        print("Could not read/open file: %s" % os.path.join(os.path.dirname(__file__), fname))
        return ''

setup(
  name = name,
  packages = [name],
  package_dir = {name: "romanize"},
  package_data = {
    name: ['*.py']
  },
  install_requires = [],
  version = version,
  description = 'Romanize - Transliteration module to romanize greek, hebrew, arabic, coptic, syriaic, phoenician, finnish, and sanskrit letters to the single roman letter equivalents and back',
  long_description = read('README'),
  author = 'Marko Manninen',
  author_email = 'elonmedia@gmail.com',

  url = 'https://github.com/markomanninen/%s' % name,
  download_url = 'https://github.com/markomanninen/%s/archive/%s.tar.gz' % (name, version),
  keywords = ['python', 'text analysis', 'transliteration'],
  platforms = ['any'],

  classifiers = [
    "Development Status :: 3 - Alpha",
    "Intended Audience :: Developers",
    "License :: OSI Approved :: MIT License",
    "Operating System :: OS Independent",
    "Programming Language :: Python",
    "Topic :: Software Development :: Libraries",
  ]
)



#!/usr/local/bin/python
# -*- coding: utf-8 -*-
# file: ara.py

import re
from collections import OrderedDict
from .romanizer import romanizer

has_capitals = False

data = OrderedDict()

# https://en.wikipedia.org/wiki/Aramaic_alphabet
# https://en.wikipedia.org/wiki/Abjad_numerals

# letters from ا to ط
# https://en.wikipedia.org/wiki/%D8%A7
data['alif'] = dict(letter=[u'ا'], name=u'ا', segment='vowel', subsegment='', transliteration=u'a', order=1)
# https://en.wikipedia.org/wiki/%D8%A8
data['ba'] = dict(letter=[u'ب'], name=u'ب', segment='consonant', subsegment='', transliteration=u'b', order=2)
# https://en.wikipedia.org/wiki/%D8%AC
data['jim'] = dict(letter=[u'ج'], name=u'ج', segment='consonant', subsegment='', transliteration=u'j', order=3)
# https://en.wikipedia.org/wiki/%D8%AF
data['dal'] = dict(letter=[u'د'], name=u'د', segment='consonant', subsegment='', transliteration=u'd', order=4)
# https://en.wikipedia.org/wiki/%D9%87
data['ha'] = dict(letter=[u'ه'], name=u'ه', segment='vowel', subsegment='', transliteration=u'h', order=5)
# https://en.wikipedia.org/wiki/%D9%88
data['waw'] = dict(letter=[u'و'], name=u'و', segment='vowel', subsegment='', transliteration=u'w', order=6)
# https://en.wikipedia.org/wiki/%D8%B2
data['zayn'] = dict(letter=[u'ز'], name=u'ز', segment='consonant', subsegment='', transliteration=u'z', order=7)
# https://en.wikipedia.org/wiki/%D8%AD
data['ha'] = dict(letter=[u'ح'], name=u'ح', segment='consonant', subsegment='', transliteration=u'ḥ', order=8)
# https://en.wikipedia.org/wiki/%D8%B7
data['ta'] = dict(letter=[u'ط'], name=u'ط', segment='consonant', subsegment='', transliteration=u'ṭ', order=9)

# letters from ى to ص
# https://en.wikipedia.org/wiki/%D9%89
data['ya'] = dict(letter=[u'ى'], name=u'ى', segment='vowel', subsegment='', transliteration=u'i', order=10)
# https://en.wikipedia.org/wiki/%D9%83
data['kaf'] = dict(letter=[u'ك'], name=u'ك', segment='consonant', subsegment='', transliteration=u'k', order=11)
# https://en.wikipedia.org/wiki/%D9%84
data['lam'] = dict(letter=[u'ل'], name=u'ل', segment='consonant', subsegment='', transliteration=u'l', order=12)
# https://en.wikipedia.org/wiki/%D9%85
data['mim'] = dict(letter=[u'م'], name=u'م', segment='consonant', subsegment='', transliteration=u'm', order=13)
# https://en.wikipedia.org/wiki/%D9%86
data['nun'] = dict(letter=[u'ن'], name=u'ن', segment='consonant', subsegment='', transliteration=u'n', order=14)
# https://en.wikipedia.org/wiki/%D8%B3
data['sin'] = dict(letter=[u'س'], name=u'س', segment='consonant', subsegment='', transliteration=u's', order=15)
# https://en.wikipedia.org/wiki/%D8%B9
data['ayn'] = dict(letter=[u'ع'], name=u'ع', segment='consonant', subsegment='', transliteration=u'ʻ', order=16)
# https://en.wikipedia.org/wiki/%D9%81
data['fa'] = dict(letter=[u'ف'], name=u'ف', segment='consonant', subsegment='', transliteration=u'f', order=17)
# https://en.wikipedia.org/wiki/%D8%B5
data['sad'] = dict(letter=[u'ص'], name=u'ص', segment='consonant', subsegment='', transliteration=u'ṣ', order=18)

# letters from ق to غ
# https://en.wikipedia.org/wiki/%D9%82
data['qaf'] = dict(letter=[u'ق'], name=u'ق', segment='consonant', subsegment='', transliteration=u'q', order=19)
# https://en.wikipedia.org/wiki/%D8%B1
data['ra'] = dict(letter=[u'ر'], name=u'ر', segment='consonant', subsegment='', transliteration=u'r', order=20)
# https://en.wikipedia.org/wiki/%D8%B4
data['shin'] = dict(letter=[u'ش'], name=u'ش', segment='consonant', subsegment='', transliteration=u'š', order=21)
# https://en.wikipedia.org/wiki/%D8%AA
data['ta'] = dict(letter=[u'ت'], name=u'ت', segment='consonant', subsegment='', transliteration=u't', order=22)
# https://en.wikipedia.org/wiki/%D8%AB
data['tha'] = dict(letter=[u'ث'], name=u'ث', segment='consonant', subsegment='', transliteration=u'ṯ', order=23)
# https://en.wikipedia.org/wiki/%D8%AE
data['kha'] = dict(letter=[u'خ'], name=u'خ', segment='consonant', subsegment='', transliteration=u'ḵ', order=24)
# https://en.wikipedia.org/wiki/%D8%B0
data['dhal'] = dict(letter=[u'ذ'], name=u'ذ', segment='consonant', subsegment='', transliteration=u'ḏ', order=25)
# https://en.wikipedia.org/wiki/%D8%B6
data['dad'] = dict(letter=[u'ض'], name=u'ض', segment='consonant', subsegment='', transliteration=u'ḍ', order=26)
# https://en.wikipedia.org/wiki/%D8%B8
data['za'] = dict(letter=[u'ظ'], name=u'ظ', segment='consonant', subsegment='', transliteration=u'ẓ', order=27)
# https://en.wikipedia.org/wiki/%D8%BA
data['ghayn'] = dict(letter=[u'غ'], name=u'غ', segment='consonant', subsegment='', transliteration=u'g', order=28)

r = romanizer(data, False)

# collect arabic and transliteration letters from data dictionary for preprocessing function
letters = ''.join([''.join(d['letter'])+d['transliteration'] for key, d in data.items()])
regex = re.compile('[^%s ]+' % letters)
regex2 = re.compile('[^%s\s]' % ''.join([''.join(d['letter']) for key, d in data.items()]))

r = romanizer(data)

def filter(string):
    """
    Preprocess string to remove all other characters but arabic ones

    :param string:
    :return:
    """
    # remove all unwanted characters
    return regex2.sub(' ', string)

def preprocess(string):
    """
    Preprocess string to transform all diacritics and remove other special characters

    :param string:
    :return:
    """
    return regex.sub('', string)

def convert(string, sanitize=False):
    """
    Swap characters from script to transliterated version and vice versa.
    Optionally sanitize string by using preprocess function.

    :param sanitize:
    :param string:
    :return:
    """
    return r.convert(string, (preprocess if sanitize else False))



#!/usr/local/bin/python
# -*- coding: utf-8 -*-
# file: san.py

import re
from collections import OrderedDict
from .romanizer import romanizer

has_capitals = False

# https://en.wikipedia.org/wiki/Katapayadi_system

data = OrderedDict()

r = romanizer(data)

def filter(string):
    """
    Preprocess string to remove all other characters but sanskrit ones

    :param string:
    :return:
    """
    # remove all unwanted characters
    return string

def preprocess(string):
    """
    Preprocess string to transform all diacritics and remove other special characters

    :param string:
    :return:
    """
    return string

def convert(string, sanitize=False):
    """
    Swap characters from script to transliterated version and vice versa.
    Optionally sanitize string by using preprocess function.

    :param sanitize:
    :param string:
    :return:
    """
    return r.convert(string, (preprocess if sanitize else False))



#!/usr/local/bin/python
# -*- coding: utf-8 -*-
# file: syc.py

import re
from collections import OrderedDict
from .romanizer import romanizer

has_capitals = False

data = OrderedDict()

# https://en.wikipedia.org/wiki/Aramaic_alphabet

# letters from ܐ to ܛ
# alef:http://en.wiktionary.org/wiki/
data['alap'] = dict(letter=[u'ܐ'], name=u'ܐ', segment='vowel', subsegment='', transliteration=u'a', order=1)
# beth:http://en.wiktionary.org/wiki/
data['beth'] = dict(letter=[u'ܒ'], name=u'ܒ', segment='consonant', subsegment='', transliteration=u'b', order=2)
# gimel:http://en.wiktionary.org/wiki/
data['gamal'] = dict(letter=[u'ܓ'], name=u'ܓ', segment='consonant', subsegment='', transliteration=u'g', order=3)
# daleth:http://en.wiktionary.org/wiki/
data['dalath'] = dict(letter=[u'ܕ'], name=u'ܕ', segment='consonant', subsegment='', transliteration=u'd', order=4)
# he:http://en.wiktionary.org/wiki/
data['he'] = dict(letter=[u'ܗ'], name=u'ܗ', segment='vowel', subsegment='', transliteration=u'e', order=5)
# vau:http://en.wikipedia.org/wiki/
data['waw'] = dict(letter=[u'ܘ'], name=u'ܘ', segment='vowel', subsegment='', transliteration=u'w', order=6)
# zayin:http://en.wiktionary.org/wiki/
data['zain'] = dict(letter=[u'ܙ'], name=u'ܙ', segment='consonant', subsegment='', transliteration=u'z', order=7)
# heth:http://en.wiktionary.org/wiki/
data['heth'] = dict(letter=[u'ܚ'], name=u'ܚ', segment='consonant', subsegment='', transliteration=u'ê', order=8)
# teth:http://en.wiktionary.org/wiki/
data['teth'] = dict(letter=[u'ܛ'], name=u'ܛ', segment='consonant', subsegment='', transliteration=u'h', order=9)

# letters from ܝ to ܨ
# yod:http://en.wiktionary.org/wiki/
data['yodh'] = dict(letter=[u'ܝ'], name=u'ܝ', segment='vowel', subsegment='', transliteration=u'i', order=10)
# kaph:http://en.wiktionary.org/wiki/
data['kap'] = dict(letter=[u'ܟ'], name=u'ܟ', segment='consonant', subsegment='', transliteration=u'k', order=11)
# lamed:http://en.wiktionary.org/wiki/
data['lamadh'] = dict(letter=[u'ܠ'], name=u'ܠ', segment='consonant', subsegment='', transliteration=u'l', order=12)
# mem:http://en.wiktionary.org/wiki/
data['mem'] = dict(letter=[u'ܡ'], name=u'ܡ', segment='consonant', subsegment='', transliteration=u'm', order=13)
# num:http://en.wiktionary.org/wiki/
data['num'] = dict(letter=[u'ܢ'], name=u'ܢ', segment='consonant', subsegment='', transliteration=u'n', order=14)
# samekh:http://en.wiktionary.org/wiki/
data['semkath'] = dict(letter=[u'ܣ'], name=u'ܣ', segment='consonant', subsegment='', transliteration=u'x', order=15)
# ayin:http://en.wiktionary.org/wiki/
data['e'] = dict(letter=[u'ܥ'], name=u'ܥ', segment='consonant', subsegment='', transliteration=u'o', order=16)
# pe:http://en.wiktionary.org/wiki/
data['pe'] = dict(letter=[u'ܦ'], name=u'ܦ', segment='consonant', subsegment='', transliteration=u'p', order=17)
# tsade:http://en.wikipedia.org/wiki/
data['sadhe'] = dict(letter=[u'ܨ'], name=u'ܨ', segment='consonant', subsegment='', transliteration=u'c', order=18)

# letters from ܩ to ܬ
# resh:http://en.wiktionary.org/wiki/
data['qop'] = dict(letter=[u'ܩ'], name=u'ܩ', segment='consonant', subsegment='', transliteration=u'q', order=19)
# shin:http://en.wiktionary.org/wiki/
data['resh'] = dict(letter=[u'ܪ'], name=u'ܪ', segment='consonant', subsegment='', transliteration=u'r', order=20)
# tau:http://en.wiktionary.org/wiki/
data['shin'] = dict(letter=[u'ܫ'], name=u'ܫ', segment='consonant', subsegment='', transliteration=u's', order=21)
# final_tsade:http://en.wiktionary.org/wiki/
data['taw'] = dict(letter=[u'ܬ'], name=u'ܬ', segment='consonant', subsegment='', transliteration=u't', order=22)
# final_kaph:http://en.wiktionary.org/wiki/
#data['final_kap'] = dict(letter=[u'ⲫ'], name=u'ⲫ', segment='consonant', subsegment='', transliteration=u'K', order=23)
# final_mem, chi:http://en.wiktionⲣary.org/wiki/
#data['final_mem'] = dict(letter=[u'ⲭ'], name=u'ⲭ', segment='consonant', subsegment='', transliteration=u'M', order=24)
# final_nun:http://en.wiktionary.org/wiki/
#data['final_nun'] = dict(letter=[u'ⲯ'], name=u'ⲯ', segment='consonant', subsegment='', transliteration=u'N', order=25)
# final_pe:http://en.wiktionary.org/wiki/
#data['final_pe'] = dict(letter=[u'ⲱ'], name=u'ⲱ', segment='consonant', subsegment='', transliteration=u'P', order=26)
# final_tsade:http://en.wiktionary.org/wiki/
#data['final_sadhe'] = dict(letter=[u'ⳁ'], name=u'ⳁ', segment='consonant', subsegment='', transliteration=u'Y', order=27)

r = romanizer(data, False)

# collect syriaic and transliteration letters from data dictionary for preprocessing function
letters = ''.join([''.join(d['letter'])+d['transliteration'] for key, d in data.items()])
regex = re.compile('[^%s ]+' % letters)
regex2 = re.compile('[^%s\s]' % ''.join([''.join(d['letter']) for key, d in data.items()]))

r = romanizer(data)

def filter(string):
    """
    Preprocess string to remove all other characters but syriaic ones

    :param string:
    :return:
    """
    # remove all unwanted characters
    return regex2.sub(' ', string)

def preprocess(string):
    """
    Preprocess string to transform all diacritics and remove other special characters

    :param string:
    :return:
    """
    return regex.sub('', string)

def convert(string, sanitize=False):
    """
    Swap characters from script to transliterated version and vice versa.
    Optionally sanitize string by using preprocess function.

    :param sanitize:
    :param string:
    :return:
    """
    return r.convert(string, (preprocess if sanitize else False))
